#!/usr/bin/env bash

>&2 echo "Syncing production WordPress database to local."

## Exit if pipe fails ##
set -o pipefail

## Source scripts
vendor_brewpixel_barista_bin_wp_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

source "${vendor_brewpixel_barista_bin_wp_dir}/../../Burr/burr-dependencies.sh"
ensure_readlink_installed

if [[ "$OSTYPE" == "linux-gnu" ]]; then
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
elif [[ "$OSTYPE" == "darwin"* ]]; then
	# Mac OSX
	vendor_brewpixel_barista_bin_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(greadlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(greadlink -f $(dirname "${vendor_dir}"))
else
    # Unknown.
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_wp_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
fi

## Source scripts
source "${vendor_brewpixel_barista_dir}/config.sh"
source "${vendor_brewpixel_barista_dir}/Burr/bootstrap.sh"

#source "${vendor_brewpixel_barista_dir}/../bashful/bin/bashful"

for f in $(ls "${vendor_brewpixel_barista_dir}/Burr/");
    do source "${vendor_brewpixel_barista_dir}/Burr/${f}";
done

>&2 echo "${project_base}"
cd "${project_base}" || exit

# Before continuing, check that the database prefix matches production
db_prefix_local=$(wp db prefix)
>&2 echo "$db_prefix_local"
db_prefix_production=$(ssh ${ssh_user}@${ssh_ip} "cd "${project_base}" && wp db prefix")
>&2 echo "$db_prefix_production"
if [ "$db_prefix_local" = "$db_prefix_production" ]; then
    >&2 echo "Local and production database table prefixes match."
else
    die "Local and production database table prefixes do not match. Please fix this so they match before attempting to synchronise them again."
fi

# Drop local database
#wp db drop --yes
# Create local database
#wp db create
# Runs DROP_DATABASE and CREATE_DATABASE SQL statements using DB_HOST, DB_NAME,
# DB_USER and DB_PASSWORD database credentials specified in wp-config.php.
wp db reset --yes

eval "$(parse_yaml "${project_base}/wp-cli.yml")"
>&2 echo "Location of WordPress: $path"
>&2 echo "SSH user: $ssh_user"
>&2 echo "SSH IP: $ssh_ip"

### Export and download production database. Import production database file into local database ###
ssh ${ssh_user}@${ssh_ip} "cd "${project_base}" && wp db export --single-transaction --opt --quote-names --complete-insert --compress - | gzip -9" | gzip -d | wp db import -

# Search and replace production URLs to local
wp search-replace "${main_repo_name}" "${domain_without_tld}.local" --skip-columns=guid --all-tables
wp search-replace "www.${domain_without_tld}.local" "${domain_without_tld}.local" --skip-columns=guid --all-tables
wp search-replace "${domain_without_tld}.local/wp-content" "${domain_without_tld}.local/content" --skip-columns=guid --all-tables
wp search-replace "${domain_without_tld}.local\/wp-content" "${domain_without_tld}.local\/content" --skip-columns=guid --all-tables
wp search-replace "${domain_without_tld}.local%2Fwp-content" "${domain_without_tld}.local%2Fcontent" --skip-columns=guid --all-tables
wp search-replace 'wp-content/uploads' 'content/uploads' --skip-columns=guid --all-tables
wp search-replace 'wp-content\/uploads' 'content\/uploads' --skip-columns=guid --all-tables
wp option update blog_public 0

>&2 echo "Finished syncing production WordPress database to local."
